BraSCII - Wikipedia

# BraSCII

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

BraSCII
Alias(es) | ABNT
Language(s) | Portuguese, English, various others
Standard | ABNT NBR 9611:1991
Classification | Extended ASCII
Extends | ECMA-94:1985
Based on | DEC MCS
Other related encoding(s) | ISO-8859-1 (ECMA-94:1986 or later)

BraSCII is an encoded repertoire of characters that was used in Brazil. It was used in the 1980s on several printers, in applications like Carta Certa [pt], in video boards[citation needed] and it was the standard character set in the Brazilian line of MSX computers.[1] This code page is known by Star printers as Code page 3847.

## History[edit]

This character set was devised in 1986[2] by the Brazilian National Standards Organization (Associação Brasileira de Normas Técnicas (ABNT)) through the standard NBR-9614:1986 and later revised in 1991 in the standard NBR-9611:1991.[3]

The code is based on the ISO/IEC 4873[4] standards, and it was nicknamed “BraSCII” (Brazilian Standard Code for Information Interchange) in analogy to “American Standard Code for Information Interchange” (ASCII). While ASCII is a 7-bit code, BraSCII is an 8-bit code,[4] where the characters from 160 to 255 were configured to support extended characters. It is nearly identical to ECMA-94 (1985) and ISO 8859-1 (1987) except that the characters × and ÷ are replaced by Œ and œ,[5][6][7] as they still were in the Multinational Character Set (MCS, 1983) and Lotus International Character Set (LICS, 1985), whereas these code points were empty in the earliest versions of ECMA-94 (1985)[8] and ISO 8859-1. However, it is completely identical for the first draft of ECMA-94 and ISO 8859-1. In some other devices, this character set is simply referred as “ABNT”.

This character set[9] was different from the other Brazilian character set, ABICOMP.

The goal of this character set was to eliminate the “Babel’s Tower”[4] of the existing coding systems for the Portuguese language (ISO IR-16, ISO IR-84, IBM 256 , IBM 275, IBM 850, DEC Multinational, HP Roman-8, Mac OS Roman, etc.). In spite of that, this code set had troubles in imposing itself,[2][4] mainly due to the pressure of big multinational corporations and finished by being less and less used because of the ubiquity of other character sets (ISO 8859-1 and later Unicode).

## Coverage[edit]

Each character is encoded as a single eight-bit code value. These code values can be used in almost any data interchange system to communicate in the following languages (with a few exceptions due to missing characters, as noted):

### Modern languages with complete coverage[edit]

Afrikaans Albanian Basque Breton Corsican Danish[a] English[b] | Faroese Galician German Icelandic Irish Indonesian Italian | Leonese Luxembourgish[c] Malay[d] Manx Norwegian[e] Occitan | Portuguese[f] Rhaeto-Romanic Scottish Gaelic Scots Spanish Swahili Swedish Tagalog Walloon

Notes

1. ^ Complete support except for Ǿ/ǿ which are missing. Ǿ/ǿ can be replaced with Ø/ø or øe at the cost of increased ambiguity.
2. ^ US and modern British.
3. ^ Basic classical orthography.
4. ^ Rumi script.
5. ^ Bokmål and Nynorsk.
6. ^ European and Brazilian.

The letter ÿ, which appears in French only very rarely, and never at the beginning of words, is included only in lowercase form. The slot corresponding to its uppercase form is occupied by the lowercase letter ß from the German language, which itself is rarely used in its uppercase form.

BraSCII
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
1_ 16 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
2_ 32 | SP 0020 | ! 0021 | " 0022 | # 0023 | $ 0024 | % 0025 | & 0026 | ' 0027 | ( 0028 | ) 0029 | * 002A | + 002B | , 002C | - 002D | . 002E | / 002F
3_ 48 | 0 0030 | 1 0031 | 2 0032 | 3 0033 | 4 0034 | 5 0035 | 6 0036 | 7 0037 | 8 0038 | 9 0039 | : 003A | ; 003B | < 003C | = 003D | > 003E | ? 003F
4_ 64 | @ 0040 | A 0041 | B 0042 | C 0043 | D 0044 | E 0045 | F 0046 | G 0047 | H 0048 | I 0049 | J 004A | K 004B | L 004C | M 004D | N 004E | O 004F
5_ 80 | P 0050 | Q 0051 | R 0052 | S 0053 | T 0054 | U 0055 | V 0056 | W 0057 | X 0058 | Y 0059 | Z 005A | [ 005B | \ 005C | ] 005D | ^ 005E | _ 005F
6_ 96 | ` 0060 | a 0061 | b 0062 | c 0063 | d 0064 | e 0065 | f 0066 | g 0067 | h 0068 | i 0069 | j 006A | k 006B | l 006C | m 006D | n 006E | o 006F
7_ 112 | p 0070 | q 0071 | r 0072 | s 0073 | t 0074 | u 0075 | v 0076 | w 0077 | x 0078 | y 0079 | z 007A | { 007B | | 007C | } 007D | ~ 007E |
8_ 128 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
9_ 144 |  |  |  |  |  |  |  |  |  |  |  |  |  |  |  |
A_ 160 | NBSP 00A0 | ¡ 00A1 | ¢ 00A2 | £ 00A3 | ¤ 00A4 | ¥ 00A5 | ¦ 00A6 | § 00A7 | ¨ 00A8 | © 00A9 | ª 00AA | « 00AB | ¬ 00AC | SHY 00AD | ® 00AE | ¯ 00AF
B_ 176 | ° 00B0 | ± 00B1 | ² 00B2 | ³ 00B3 | ´ 00B4 | µ 00B5 | ¶ 00B6 | · 00B7 | ¸ 00B8 | ¹ 00B9 | º 00BA | » 00BB | ¼ 00BC | ½ 00BD | ¾ 00BE | ¿ 00BF
C_ 192 | À 00C0 | Á 00C1 | Â 00C2 | Ã 00C3 | Ä 00C4 | Å 00C5 | Æ 00C6 | Ç 00C7 | È 00C8 | É 00C9 | Ê 00CA | Ë 00CB | Ì 00CC | Í 00CD | Î 00CE | Ï 00CF
D_ 208 | Ð 00D0 | Ñ 00D1 | Ò 00D2 | Ó 00D3 | Ô 00D4 | Õ 00D5 | Ö 00D6 | Œ 0152 | Ø 00D8 | Ù 00D9 | Ú 00DA | Û 00DB | Ü 00DC | Ý 00DD | Þ 00DE | ß 00DF
E_ 224 | à 00E0 | á 00E1 | â 00E2 | ã 00E3 | ä 00E4 | å 00E5 | æ 00E6 | ç 00E7 | è 00E8 | é 00E9 | ê 00EA | ë 00EB | ì 00EC | í 00ED | î 00EE | ï 00EF
F_ 240 | ð 00F0 | ñ 00F1 | ò 00F2 | ó 00F3 | ô 00F4 | õ 00F5 | ö 00F6 | œ 0153 | ø 00F8 | ù 00F9 | ú 00FA | û 00FB | ü 00FC | ý 00FD | þ 00FE | ÿ 00FF

Letter Number Punctuation Symbol Other Undefined Differences from ISO 8859-1

## References[edit]

1. ^
   "[Feature] MSX models are too european-centric for a japanese standard [sf#211] #235". github.com.
2. ^ a b "A batalha dos protocolos de redes de computadores localizada (no Brasil) no fim do Século XX" (PDF). Archived from the original (PDF) on 2017-12-15. Retrieved 2017-02-25.
3. ^ Ficha descritiva da norma NBR-9611 at ABNT site
4. ^ a b c d Indústria Brasileira de Computadores — Perspectivas até os anos 90
5. ^ "Epson Stylus Color 200 User Guide - PC865 Nordic, Abicomp, BRASCII". twinhead.manuals365.com.
6. ^ "Star LC 8021 User's Manual" (PDF).
7. ^ "User manual for Brother HL-2135W - a user manual, servicing manual, settings and specifications ofBrother HL-2135W - page 136 - User manuals and advice for your devices - User-Manual.info". www.user-manual.info.
8. ^ Standard ECMA-94: 8-bit Single-Byte Coded Graphic Character Set (PDF) (1 ed.). European Computer Manufacturers Association (ECMA). March 1985 [1984-12-14]. Archived (PDF) from the original on 2016-12-02. Retrieved 2016-12-01.
9. ^ "Oki Data OKIPOS 425 D Developer's Guide 6.2.2.7 Abicomp". my.okidata.com.

Retrieved from "https://en.wikipedia.org/w/index.php?title=BraSCII&oldid=998096448"
Categories:

- Character sets
- History of Brazil
- Information technology in Brazil

Hidden categories:

- All articles with unsourced statements
- Articles with unsourced statements from February 2017